/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.codehaus.groovy.runtime;

import groovy.lang.GroovyClassLoader;
import junit.framework.TestCase;

import java.lang.reflect.Field;

class X {

    public static int field = 0;

    static {
        StaticInitTest.failed = true;
    }
}

public class StaticInitTest extends TestCase {

    static boolean failed;

    public void testInitOrder () throws NoSuchFieldException, IllegalAccessException, ClassNotFoundException {
        final Field f = new GroovyClassLoader().loadClass("org.codehaus.groovy.runtime.X", false, false, false).getField("field");
        assertTrue(!failed);
        f.getInt(null);
        assertTrue(failed);
    }
}
